@@ -14,7 +14,7 @@ use WebService::LiveJournal::EventList;
 use HTTP::Cookies;
 
 # ABSTRACT: Interface to the LiveJournal API
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 my $zero = new RPC::XML::int(0);
@@ -339,6 +339,9 @@ sub batch_console_commands
     commands => RPC::XML::array->new(@commands)
   );
   return unless defined $response;
+
+  # also returned is 'success' but as far as I can tell it is always
+  # 1, even if the command doesn't exist.  so we are ignoring it.
   
   foreach my $output (map { $_->{output} } @{ $response->value->{results} })
   {
@@ -589,7 +592,7 @@ WebService::LiveJournal::Client - Interface to the LiveJournal API
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -1056,7 +1059,6 @@ LiveJournal:
  my $password = <STDIN>;
  chomp $password;
  
- 
  my $client = WebService::LiveJournal->new(
    server => 'www.livejournal.com',
    username => $user,
@@ -1126,6 +1128,52 @@ entries are removed they cannot be brought back from the dead:
  
  print "$count entries deleted\n";
 
+Here is a really simple command line interface to the LiveJournal
+admin console.  Obvious improvements like better parsing of the commands
+and not displaying the password are left as an exercise to the reader.
+
+ use strict;
+ use warnings;
+ use WebService::LiveJournal;
+ 
+ my $client = WebService::LiveJournal->new(
+   server => 'www.livejournal.com',
+   username => do {
+     print "user: ";
+     my $user = <STDIN>;
+     chomp $user;
+     $user;
+   },
+   password => do {
+     print "pass: ";
+     my $pass = <STDIN>;
+     chomp $pass;
+     $pass;
+   },
+ );
+ 
+ while(1)
+ {
+   print "> ";
+   my $command = <STDIN>;
+   unless(defined $command)
+   {
+     print "\n";
+     last;
+   }
+   chomp $command;
+   $client->batch_console_commands(
+     [ split /\s+/, $command ],
+     sub {
+       foreach my $line (@_)
+       {
+         my($type, $text) = @$line;
+         printf "%8s : %s\n", $type, $text;
+       }
+     }
+   );
+ }
+
 =head1 HISTORY
 
 The code in this distribution was written many years ago to sync my website
